<?php
namespace Catequil\Authentication\Adapter;

use Catequil\Authentication\Service\AuthenticatedUser;
use Catequil\User\Service\UserServiceInterface;
use Laminas\Authentication\Adapter\AdapterInterface;
use Laminas\Authentication\Result;

/**
 * Class CatequilAdapter
 *
 * @package Catequil\Authentication\Adapter
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/catequil
 */
final class CatequilAdapter implements AdapterInterface
{
    private UserServiceInterface $users;
    private string $email = '';
    private string $password = '';

    /**
     * @param UserServiceInterface $users
     */
    public function __construct(UserServiceInterface $users)
    {
        $this->users = $users;
    }

    /**
     * @param string $identity
     */
    public function setIdentity(string $identity): void
    {
        $this->email = $identity;
    }

    /**
     * @param string $credential
     */
    public function setCredential(string $credential): void
    {
        $this->password = $credential;
    }

    /**
     * @return Result
     */
    public function authenticate(): Result
    {
        $user = $this->users->findUserByEmailAddress($this->email);

        if (!$user) {
            return new Result(Result::FAILURE_IDENTITY_NOT_FOUND, null);
        }

        if ($user->checkPassword($this->password)) {
            $authenticatedUser = new AuthenticatedUser($user);
            return new Result(Result::SUCCESS, $authenticatedUser->getIdentity());
        }

        return new Result(Result::FAILURE, null);
    }
}
