<?php
declare(strict_types=1);

namespace Catequil\Authentication;

use Mezzio\Authentication\UserInterface;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Mezzio\Authentication\LaminasAuthentication\LaminasAuthentication;

/**
 * Class CatequilAuthentication
 *
 * @package Catequil\Authentication
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/catequil
 */
final class CatequilAuthentication extends LaminasAuthentication
{
    public function authenticate(ServerRequestInterface $request): ?UserInterface
    {
        if ($authorization = $request->getHeaderLine('Authorization')) {
            if (preg_match('/^Basic (.+)$/', $authorization, $matches)) {
                $basic = base64_decode($matches[1]);
                [$username, $password] = explode(':', $basic);
                return $this->initiateAuthenticationRaw($username, $password);
            }
        }

        return parent::authenticate($request);
    }

    private function initiateAuthenticationRaw(string $username, string $password) : ?UserInterface
    {
        $this->auth->getAdapter()->setIdentity($username);
        $this->auth->getAdapter()->setCredential($password);

        $result = $this->auth->authenticate();
        if (! $result->isValid()) {
            return null;
        }

        return ($this->userFactory)($result->getIdentity());
    }

    public function unauthorizedResponse(ServerRequestInterface $request) : ResponseInterface
    {
        return $this->responseFactory->createResponse()
            ->withHeader(
                'Location',
                $this->config['redirect']
            )
            ->withStatus(302);
    }
}
