<?php
declare(strict_types=1);

namespace Catequil\Authentication;

use Psr\Container\ContainerInterface;
use Psr\Http\Message\ResponseInterface;
use RuntimeException;
use Laminas\Authentication\AuthenticationService;
use Mezzio\Authentication\UserInterface;
use Mezzio\Authentication\LaminasAuthentication\LaminasAuthentication;

/**
 * Class CatequilAuthenticationFactory
 *
 * @package Catequil\Authentication
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/catequil
 */
final class CatequilAuthenticationFactory
{
    public function __invoke(ContainerInterface $container) : LaminasAuthentication
    {
        $auth = $container->has(AuthenticationService::class)
            ? $container->get(AuthenticationService::class)
            : null;

        if (null === $auth) {
            throw new RuntimeException(sprintf(
                "The %s service is missing",
                AuthenticationService::class
            ));
        }

        $config = $container->get('config')['authentication'] ?? [];

        if (! isset($config['redirect'])) {
            throw new RuntimeException(
                'The redirect URL is missing for authentication'
            );
        }

        if (! $container->has(UserInterface::class)) {
            throw new RuntimeException(
                'UserInterface factory service is missing for authentication'
            );
        }

        return new CatequilAuthentication(
            $auth,
            $config,
            $container->get(ResponseInterface::class),
            $container->get(UserInterface::class)
        );
    }
}
