<?php
namespace Catequil\Authentication;

use Laminas\Authentication\Adapter\AdapterInterface;
use Laminas\Authentication\AuthenticationService;
use Laminas\Authentication\AuthenticationServiceInterface;
use Mezzio\Authentication\AuthenticationInterface;
use Mezzio\Authentication\UserInterface;

/**
 * Class ConfigProvider
 *
 * @package Catequil\Authentication
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/catequil
 */
final class ConfigProvider
{
    /**
     * @return array
     */
    public function __invoke(): array
    {
        return [
            'authentication'      => $this->getAuthenticationConfig(),
            'dependencies'        => $this->getDependencies(),
            'routes'              => $this->getRoutes(),
            'view'                => $this->getViewConfig(),
            'templates' => [
                'paths' => [
                    __DIR__ . '/View',
                ],
            ],
        ];
    }

    /**
     * @return array
     */
    public function getAuthenticationConfig(): array
    {
        return [
            'username' => 'email',
            'redirect' => '/login',
        ];
    }

    /**
     * @return array
     */
    public function getDependencies(): array
    {
        return [
            'aliases' => [
                AdapterInterface::class        => Adapter\CatequilAdapter::class,
                AuthenticationInterface::class => CatequilAuthentication::class,
                AuthenticationServiceInterface::class => AuthenticationService::class,
                UserInterface::class           => Service\UserFactory::class,
            ],

            'factories' => [
                CatequilAuthentication::class => CatequilAuthenticationFactory::class,
                AuthenticationService::class => Service\AuthenticationServiceFactory::class,
            ],
        ];
    }

    public function getRoutes(): array
    {
        return [[
            'name' => 'auth.login',
            'path' => '/login',
            'allowed_methods' => ['GET', 'POST'],
            'middleware' => Handler\Login::class,
        ], [
            'name' => 'auth.logout',
            'path' => '/logout',
            'allowed_methods' => ['GET'],
            'middleware' => Handler\Logout::class,
        ]];
    }

    /**
     * @return array
     */
    public function getViewConfig(): array
    {
        return [
            'script_paths' => [
                __DIR__ . '/View',
            ],
        ];
    }
}
