<?php
namespace Catequil\Authentication\Handler;

use Catequil\Authentication\Form\LoginForm;
use Laminas\Form\FormElementManager;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\RequestHandlerInterface;
use Laminas\Diactoros\Response\HtmlResponse;
use Laminas\Diactoros\Response\RedirectResponse;
use Mezzio\Authentication\AuthenticationInterface;
use Laminas\Form\FormInterface;
use Laminas\View\Renderer\RendererInterface;

/**
 * Class Login
 *
 * @package Catequil\Authentication\Handler
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/catequil
 */
final class Login implements RequestHandlerInterface
{
    private AuthenticationInterface $auth;
    private RendererInterface $renderer;
    private FormElementManager $forms;

    /**
     * Login constructor.
     * @param AuthenticationInterface $auth
     * @param RendererInterface $renderer
     * @param FormElementManager $forms
     */
    public function __construct(
        AuthenticationInterface $auth,
        RendererInterface $renderer,
        FormElementManager $forms
    ) {
        $this->auth = $auth;
        $this->renderer = $renderer;
        $this->forms = $forms;
    }

    /**
     * Handles a request and produces a response.
     *
     * May call other collaborating code to generate the response.
     *
     * @param ServerRequestInterface $request
     * @return ResponseInterface
     */
    public function handle(ServerRequestInterface $request): ResponseInterface
    {
        /** @var FormInterface $form */
        $form = $this->forms->get(LoginForm::class);

        if ($request->getMethod() === 'POST') {
            $form->setData($request->getParsedBody());

            if ($form->isValid()) {
                if ($this->auth->authenticate($request)) {
                    return new RedirectResponse('/');
                }

                $message = 'Neispravna e-mail adresa i/ili lozinka!';
            }
        }

        return new HtmlResponse(
            $this->renderer->render('auth/login', [
                'message' => $message ?? null,
                'form' => $form,
            ])
        );
    }
}
