<?php
declare(strict_types=1);

namespace Catequil\Authentication\Service;

use Catequil\User\Model\UserInterface;
use Mezzio\Authentication\UserInterface as AuthenticatedUserInterface;

/**
 * Class AuthenticatedUser
 *
 * @package Catequil\Authentication\Service
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/catequil
 */
final class AuthenticatedUser implements AuthenticatedUserInterface
{
    private UserInterface $user;

    /**
     * @param UserInterface $user
     */
    public function __construct(UserInterface $user)
    {
        $this->user = $user;
    }

    public function getIdentity(): string
    {
        return $this->user->getEmailAddress();
    }

    public function getRoles(): iterable
    {
        return [];
    }

    /**
     * @return UserInterface
     */
    public function getUser(): UserInterface
    {
        return $this->user;
    }

    public function getDetail(string $name, $default = null)
    {
        return $this->getDetails()[$name] ?? $default;
    }

    public function getDetails(): array
    {
        return [
            'name' => $this->user->getName(),
        ];
    }
}