<?php
declare(strict_types=1);

namespace Catequil\Authentication\Service;

use Interop\Container\ContainerInterface;
use Laminas\Authentication\Adapter\AdapterInterface;
use Laminas\Authentication\AuthenticationService;
use Laminas\Authentication\Storage\Session as SessionStorage;
use Laminas\ServiceManager\Factory\FactoryInterface;
use Laminas\Session\SessionManager;

/**
 * Class AuthenticationServiceFactory
 *
 * @package Catequil\Authentication\Service
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/catequil
 */
final class AuthenticationServiceFactory implements FactoryInterface
{
    /**
     * @param ContainerInterface $container
     * @param string $requestedName
     * @param array|null $options
     * @return object|void
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $manager = new SessionManager();
        $manager->rememberMe(365 * 86400);

        $storage = new SessionStorage('auth', null, $manager);

        return new AuthenticationService(
            null,
            $container->get(AdapterInterface::class)
        );
    }
}
